---
title: <span class="badge object-type-scalar"></span> OpsPerMinute
---
# <span class="badge object-type-scalar"></span> OpsPerMinute

Throughput: ops/min (opm)

## Definition

```python
# Throughput: ops/min (opm)
OpsPerMinute: typing.Literal["opm"] = "opm"
```
